pub enum BasicLeafSelector<S: PlanningSolution> {
Change(EitherChangeMoveSelector<S, usize, FromSolutionEntitySelector, StaticTypedValueSelector<S, usize>>),
Swap(EitherSwapMoveSelector<S, usize, FromSolutionEntitySelector, FromSolutionEntitySelector>),
}Expand description
A monomorphized leaf selector for basic (non-list) planning variables.
Wraps either a change or swap move selector in a uniform enum so that
VecUnionSelector<S, EitherMove<S, usize>, BasicLeafSelector<S>> has a
single concrete type regardless of which selectors are active.
Variants
Change(EitherChangeMoveSelector<S, usize, FromSolutionEntitySelector, StaticTypedValueSelector<S, usize>>)
Swap(EitherSwapMoveSelector<S, usize, FromSolutionEntitySelector, FromSolutionEntitySelector>)