pub struct ListContext<S, V, DM, IDM> {Show 15 fields
pub list_len: fn(&S, usize) -> usize,
pub list_remove: fn(&mut S, usize, usize) -> Option<V>,
pub list_insert: fn(&mut S, usize, usize, V),
pub list_get: fn(&S, usize, usize) -> Option<V>,
pub list_set: fn(&mut S, usize, usize, V),
pub list_reverse: fn(&mut S, usize, usize, usize),
pub sublist_remove: fn(&mut S, usize, usize, usize) -> Vec<V>,
pub sublist_insert: fn(&mut S, usize, usize, Vec<V>),
pub ruin_remove: fn(&mut S, usize, usize) -> V,
pub ruin_insert: fn(&mut S, usize, usize, V),
pub entity_count: fn(&S) -> usize,
pub cross_distance_meter: DM,
pub intra_distance_meter: IDM,
pub variable_name: &'static str,
pub descriptor_index: usize,
/* private fields */
}Expand description
Function-pointer context for list variable solvers.
Carries all domain callbacks and distance meters needed to construct
list move selectors without requiring dyn or closures.
Fields
list_len: fn(&S, usize) -> usizeReturns the length of the list for entity i.
list_remove: fn(&mut S, usize, usize) -> Option<V>Removes element at pos from entity i, returning it (returns None if out of bounds).
list_insert: fn(&mut S, usize, usize, V)Inserts val at pos in entity i.
list_get: fn(&S, usize, usize) -> Option<V>Gets element at pos in entity i.
list_set: fn(&mut S, usize, usize, V)Replaces element at pos in entity i.
list_reverse: fn(&mut S, usize, usize, usize)Reverses the segment [start, end) in entity i.
sublist_remove: fn(&mut S, usize, usize, usize) -> Vec<V>Removes segment [start, end) from entity i.
sublist_insert: fn(&mut S, usize, usize, Vec<V>)Inserts items at pos in entity i.
ruin_remove: fn(&mut S, usize, usize) -> VRemoves element at pos from entity i for ruin moves (panics if out of bounds).
ruin_insert: fn(&mut S, usize, usize, V)Inserts val at pos in entity i for ruin reinsertion.
entity_count: fn(&S) -> usizeReturns the total number of list owner entities.
cross_distance_meter: DMCross-entity (inter-route) distance meter.
intra_distance_meter: IDMIntra-entity (intra-route) distance meter.
variable_name: &'static strList variable field name.
descriptor_index: usizeDescriptor index for the list owner entity collection.
Implementations
Sourceimpl<S, V, DM, IDM> ListContext<S, V, DM, IDM>
impl<S, V, DM, IDM> ListContext<S, V, DM, IDM>
Sourcepub fn new(
list_len: fn(&S, usize) -> usize,
list_remove: fn(&mut S, usize, usize) -> Option<V>,
list_insert: fn(&mut S, usize, usize, V),
list_get: fn(&S, usize, usize) -> Option<V>,
list_set: fn(&mut S, usize, usize, V),
list_reverse: fn(&mut S, usize, usize, usize),
sublist_remove: fn(&mut S, usize, usize, usize) -> Vec<V>,
sublist_insert: fn(&mut S, usize, usize, Vec<V>),
ruin_remove: fn(&mut S, usize, usize) -> V,
ruin_insert: fn(&mut S, usize, usize, V),
entity_count: fn(&S) -> usize,
cross_distance_meter: DM,
intra_distance_meter: IDM,
variable_name: &'static str,
descriptor_index: usize,
) -> Self
pub fn new( list_len: fn(&S, usize) -> usize, list_remove: fn(&mut S, usize, usize) -> Option<V>, list_insert: fn(&mut S, usize, usize, V), list_get: fn(&S, usize, usize) -> Option<V>, list_set: fn(&mut S, usize, usize, V), list_reverse: fn(&mut S, usize, usize, usize), sublist_remove: fn(&mut S, usize, usize, usize) -> Vec<V>, sublist_insert: fn(&mut S, usize, usize, Vec<V>), ruin_remove: fn(&mut S, usize, usize) -> V, ruin_insert: fn(&mut S, usize, usize, V), entity_count: fn(&S) -> usize, cross_distance_meter: DM, intra_distance_meter: IDM, variable_name: &'static str, descriptor_index: usize, ) -> Self
Creates a new list context.