ListLeafSelector

Enum ListLeafSelector 

pub enum ListLeafSelector<S, V, DM, IDM>{
    NearbyListChange(ListMoveNearbyListChangeSelector<S, V, DM, FromSolutionEntitySelector>),
    NearbyListSwap(ListMoveNearbyListSwapSelector<S, V, IDM, FromSolutionEntitySelector>),
    ListReverse(ListMoveListReverseSelector<S, V, FromSolutionEntitySelector>),
    SubListChange(ListMoveSubListChangeSelector<S, V, FromSolutionEntitySelector>),
    KOpt(ListMoveKOptSelector<S, V, FromSolutionEntitySelector>),
    ListRuin(ListMoveListRuinSelector<S, V>),
    ListChange(ListMoveListChangeSelector<S, V, FromSolutionEntitySelector>),
    ListSwap(ListMoveListSwapSelector<S, V, FromSolutionEntitySelector>),
    SubListSwap(ListMoveSubListSwapSelector<S, V, FromSolutionEntitySelector>),
}
A monomorphized leaf selector for list planning variables.

Each variant wraps one of the available list move selector wrapper types. Allows VecUnionSelector<S, ListMoveImpl<S, V>, ListLeafSelector<S, V, DM, IDM>> to have a single concrete type regardless of configuration.

Variants



NearbyListChange(ListMoveNearbyListChangeSelector<S, V, DM, FromSolutionEntitySelector>)

Nearby list change (distance-pruned relocation).



NearbyListSwap(ListMoveNearbyListSwapSelector<S, V, IDM, FromSolutionEntitySelector>)

Nearby list swap (distance-pruned swap).



ListReverse(ListMoveListReverseSelector<S, V, FromSolutionEntitySelector>)

List reverse (2-opt).



SubListChange(ListMoveSubListChangeSelector<S, V, FromSolutionEntitySelector>)

Sublist change (Or-opt).



KOpt(ListMoveKOptSelector<S, V, FromSolutionEntitySelector>)

K-opt.



ListRuin(ListMoveListRuinSelector<S, V>)

List ruin (LNS).



ListChange(ListMoveListChangeSelector<S, V, FromSolutionEntitySelector>)

Full list change (unrestricted relocation).



ListSwap(ListMoveListSwapSelector<S, V, FromSolutionEntitySelector>)

Full list swap (unrestricted swap).



SubListSwap(ListMoveSubListSwapSelector<S, V, FromSolutionEntitySelector>)

Sublist swap.