Module search

Module search 

Structs

CustomPhaseNode
NoDynamicExtensions
Empty registry used by host-language dynamic models.
NoTypedExtensions
PartitionedPhaseNode
SearchBuilder
SearchContext

Enums

NoRuntimeExtensionPhase
RuntimeExtensionPolicy
Policy carried by one concrete extension registry.

Traits

CustomSearchPhase
RuntimeExtensionRegistry
Recursive, concrete extension registry owned by a compiled runtime graph.
Search
Typed search authoring declaration consumed by the configured runtime.

Functions

local_search