Search

Trait Search 

pub trait Search<S, V = usize, DM = DefaultCrossEntityDistanceMeter, IDM = DefaultCrossEntityDistanceMeter>
where S: PlanningSolution + 'static, S::Score: Score + ParseableScore, V: Clone + Copy + PartialEq + Eq + Hash + Into<usize> + Send + Sync + Debug + 'static, DM: CrossEntityDistanceMeter<S> + Clone + Debug + Send + 'static, IDM: CrossEntityDistanceMeter<S> + Clone + Debug + Send + 'static,
{ type Extensions: RuntimeExtensionRegistry<S, V, DM, IDM>; }
Typed search authoring declaration consumed by the configured runtime.

Implementations declare one descriptor-resolved runtime model and one concrete typed-extension registry. The configured runner is the sole owner of graph compilation and per-solve phase preparation.

Required Associated Types

type Extensions: RuntimeExtensionRegistry<S, V, DM, IDM>

Concrete typed extension registry transferred with this declaration.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<S, V, DM, IDM, Extensions> Search<S, V, DM, IDM> for SearchBuilder<S, V, DM, IDM, Extensions>
where S: PlanningSolution + 'static, S::Score: Score + ParseableScore, V: Clone + Copy + PartialEq + Eq + Hash + Into<usize> + Send + Sync + Debug + 'static, DM: CrossEntityDistanceMeter<S> + Clone + Debug + Send + 'static, IDM: CrossEntityDistanceMeter<S> + Clone + Debug + Send + 'static, Extensions: RuntimeExtensionRegistry<S, V, DM, IDM>,

Source

type Extensions = Extensions