pub enum ScalarMoveUnion<S, V> {
Change(ChangeMove<S, V>),
Swap(SwapMove<S, V>),
PillarChange(PillarChangeMove<S, V>),
PillarSwap(PillarSwapMove<S, V>),
RuinRecreate(RuinRecreateMove<S>),
Composite(SequentialCompositeMove<S, ScalarMoveUnion<S, V>>),
CompoundScalar(CompoundScalarMove<S>),
ConflictRepair(ConflictRepairMove<S>),
}Expand description
A monomorphized union of the canonical scalar move family.
Implements Move<S> by delegating to the inner variant.
Copy when V: Copy, avoiding heap allocation in the move selector hot path.
Variants
Change(ChangeMove<S, V>)
Swap(SwapMove<S, V>)
PillarChange(PillarChangeMove<S, V>)
PillarSwap(PillarSwapMove<S, V>)
RuinRecreate(RuinRecreateMove<S>)
Composite(SequentialCompositeMove<S, ScalarMoveUnion<S, V>>)
CompoundScalar(CompoundScalarMove<S>)
ConflictRepair(ConflictRepairMove<S>)