pub struct ListReverseMove<S, V> { /* private fields */ }Expand description
A move that reverses a segment within a list.
This is the fundamental 2-opt move for TSP. Reversing a segment of the tour can significantly reduce total distance by eliminating crossing edges.
Type Parameters
S- The planning solution typeV- The list element value type
Example
use solverforge_solver::heuristic::r#move::ListReverseMove;
use solverforge_core::domain::PlanningSolution;
use solverforge_core::score::SoftScore;
#[derive(Clone, Debug)]
struct Tour { cities: Vec<i32>, score: Option<SoftScore> }
impl PlanningSolution for Tour {
type Score = SoftScore;
fn score(&self) -> Option<Self::Score> { self.score }
fn set_score(&mut self, score: Option<Self::Score>) { self.score = score; }
}
fn list_len(s: &Tour, _: usize) -> usize { s.cities.len() }
fn list_reverse(s: &mut Tour, _: usize, start: usize, end: usize) {
s.cities[start..end].reverse();
}
// Reverse segment [1..4) in tour: [A, B, C, D, E] -> [A, D, C, B, E]
let m = ListReverseMove::<Tour, i32>::new(
0, 1, 4,
list_len, list_reverse,
"cities", 0,
);Implementations
Sourceimpl<S, V> ListReverseMove<S, V>
impl<S, V> ListReverseMove<S, V>
pub fn new( entity_index: usize, start: usize, end: usize, list_len: fn(&S, usize) -> usize, list_reverse: fn(&mut S, usize, usize, usize), variable_name: &'static str, descriptor_index: usize, ) -> Self
pub fn entity_index(&self) -> usize
pub fn start(&self) -> usize
pub fn end(&self) -> usize
pub fn segment_len(&self) -> usize