Module entity

Module entity 

Entity selectors for iterating over planning entities

Structs

AllEntitiesSelector
An entity selector that iterates over all entities from all descriptors.
EntityReference
A reference to an entity within a solution.
FromSolutionEntitySelector
An entity selector that iterates over all entities from the solution.

Traits

EntitySelector
Trait for selecting entities from a planning solution.