pub enum SelectionOrder {
Inherit,
Original,
Random,
Shuffled,
Sorted,
Probabilistic,
}Variants
Implementations
Sourceimpl SelectionOrder
impl SelectionOrder
Sourcepub fn resolve(self, inherited: SelectionOrder) -> SelectionOrder
pub fn resolve(self, inherited: SelectionOrder) -> SelectionOrder
Sourcepub fn is_random(&self) -> bool
pub fn is_random(&self) -> bool
Returns true if this selection order implies random selection.
This is used to determine whether a selector should use random iteration or deterministic iteration.
Sourcepub fn requires_caching(&self) -> bool
pub fn requires_caching(&self) -> bool
Returns true if this selection order requires caching.
Some selection orders need to collect all elements before iteration can begin (e.g., Shuffled, Sorted, Probabilistic).
Sourcepub fn from_random_selection(random: bool) -> Self
pub fn from_random_selection(random: bool) -> Self
Converts from a boolean random selection flag.
Arguments
random-trueforRandom,falseforOriginal
Sourcepub fn to_random_selection(&self) -> bool
pub fn to_random_selection(&self) -> bool