pub struct KOptMoveSelector<S, V, ES> { /* private fields */ }Expand description
A move selector that generates k-opt moves.
Enumerates all valid cut point combinations for each selected entity and generates moves for each reconnection pattern.
Implementations
Sourceimpl<S: PlanningSolution, V, ES> KOptMoveSelector<S, V, ES>
impl<S: PlanningSolution, V, ES> KOptMoveSelector<S, V, ES>