pub struct NearbyKOptMoveSelector<S, V, D: ListPositionDistanceMeter<S>, ES> { /* private fields */ }Expand description
A k-opt move selector with nearby selection for improved performance.
Instead of enumerating all O(n^k) cut combinations, uses distance-based pruning to reduce to O(n * m^(k-1)) where m = max_nearby_size.
How It Works
- First cut: all positions in the route
- Second cut: only positions nearby (by element distance) to first cut
- Third cut: only positions nearby to second cut
- etc.
This dramatically reduces the search space for large routes.
Implementations
Sourceimpl<S: PlanningSolution, V, D: ListPositionDistanceMeter<S>, ES> NearbyKOptMoveSelector<S, V, D, ES>
impl<S: PlanningSolution, V, D: ListPositionDistanceMeter<S>, ES> NearbyKOptMoveSelector<S, V, D, ES>
pub fn new( entity_selector: ES, distance_meter: D, max_nearby: usize, config: KOptConfig, list_len: fn(&S, usize) -> usize, sublist_remove: fn(&mut S, usize, usize, usize) -> Vec<V>, sublist_insert: fn(&mut S, usize, usize, Vec<V>), variable_name: &'static str, descriptor_index: usize, ) -> Self