pub struct MimicRecorder { /* private fields */ }Expand description
Handle for sharing mimic state between recording and replaying selectors.
Uses a manually reference-counted heap allocation with Cell for interior
mutability. No Arc, no RwLock — all access is sequential single-threaded.
Implementations
Sourceimpl MimicRecorder
impl MimicRecorder
Sourcepub fn new(id: impl Into<String>) -> Self
pub fn new(id: impl Into<String>) -> Self
Creates a new mimic recorder with the given identifier.
Sourcepub fn get_has_next(&self) -> Option<bool>
pub fn get_has_next(&self) -> Option<bool>
Gets the recorded has_next state.
Sourcepub fn get_recorded_entity(&self) -> Option<EntityReference>
pub fn get_recorded_entity(&self) -> Option<EntityReference>
Gets the recorded entity.