Structs
- From
Solution Value Selector - A value selector that extracts values from the solution using a function pointer.
- PerEntity
Value Selector - Range
Value Selector - A value selector that generates a range of usize values 0..count.
- Static
Value Selector - A value selector with a static list of values.
Traits
- Value
Selector - A value selector that yields values of type
Vdirectly.