pub struct RangeValueSelector<S> { /* private fields */ }Expand description
A value selector that generates a range of usize values 0..count.
Uses a function pointer to get the count from the solution.
Implementations