Module manager

Module manager 

Structs

ConstraintAnalysis
ConstructionPhaseFactory
Zero-erasure factory for construction heuristic phases.
KOptPhase
K-opt local search phase.
KOptPhaseBuilder
Builder for creating k-opt local search phases.
ListCheapestInsertionPhase
List construction phase using the canonical cheapest-insertion kernel.
ListClarkeWrightPhase
Public facade for the canonical Clarke-Wright construction kernel.
ListConstructionPhase
List construction phase that assigns elements round-robin to entities.
ListConstructionPhaseBuilder
Builder for creating list construction phases.
ListKOptPhase
Per-route k-opt polishing phase for list variable problems.
ListRegretInsertionPhase
List construction phase using the canonical regret-insertion kernel.
LocalSearchPhaseFactory
Zero-erasure factory for local search phases.
ScoreAnalysis
SolverEventMetadata
SolverFactory
Zero-erasure solver factory.
SolverFactoryBuilder
Builder for SolverFactory with zero type erasure.
SolverManager
Manages retained async solve jobs with lifecycle-complete event streaming.
SolverPanicPayload
Preserves a foreign-runtime error object while giving retained solving a stable, displayable failure message.
SolverRuntime
Runtime context for a retained solve job.
SolverSnapshot
SolverSnapshotAnalysis
SolverStatus
SolverTelemetryDetail
One atomically retained diagnostic view of a job.

Enums

ConstructionType
LocalSearchAcceptorType
PhaseConfig
SolverBuildError
SolverEvent
SolverLifecycleState
SolverManagerError
SolverTerminalReason

Traits

Analyzable
Trait for solutions that can be analyzed for constraint violations.
PhaseFactory
Factory trait for creating phases with zero type erasure.
Solvable
Trait for solutions that can run inside the retained lifecycle manager.

Functions

analyze
Analyzes a solution for constraint violations.
solver_factory_builder
Creates a builder for SolverFactory.