pub struct ListCheapestInsertionPhase<S, E>{ /* private fields */ }Expand description
List construction phase using the canonical cheapest-insertion kernel.
The source key is mandatory. It is the one identity used to bind declarations, resolve assigned values, retain trace positions, and map precedence successors; the phase never falls back to payload equality or hashing.
Implementations
Sourceimpl<S, E> ListCheapestInsertionPhase<S, E>
impl<S, E> ListCheapestInsertionPhase<S, E>
Sourcepub fn new(
element_count: fn(&S) -> usize,
get_assigned: fn(&S) -> Vec<E>,
entity_count: fn(&S) -> usize,
list_len: fn(&S, usize) -> usize,
list_insert: fn(&mut S, usize, usize, E),
list_remove: fn(&mut S, usize, usize) -> E,
index_to_element: fn(&S, usize) -> E,
element_source_key: fn(&S, &E) -> usize,
descriptor_index: usize,
) -> Self
pub fn new( element_count: fn(&S) -> usize, get_assigned: fn(&S) -> Vec<E>, entity_count: fn(&S) -> usize, list_len: fn(&S, usize) -> usize, list_insert: fn(&mut S, usize, usize, E), list_remove: fn(&mut S, usize, usize) -> E, index_to_element: fn(&S, usize) -> E, element_source_key: fn(&S, &E) -> usize, descriptor_index: usize, ) -> Self
Creates a cheapest-insertion phase over an explicitly keyed source.
pub fn with_element_owner_fn( self, element_owner_fn: Option<fn(&S, &E) -> Option<usize>>, ) -> Self
pub fn with_element_order_key( self, element_order_key: Option<fn(&S, E) -> i64>, ) -> Self
pub fn with_precedence_hooks( self, duration_fn: Option<fn(&S, E) -> usize>, successors_fn: Option<fn(&S, E, &mut Vec<E>)>, ) -> Self