pub struct Placement<S, M, C = ArenaMoveCursor<S, M>>{
pub entity_ref: EntityReference,
/* private fields */
}Expand description
A placement represents an entity that needs a value assigned, along with the candidate moves to assign values.
Type Parameters
S- The planning solution typeM- The move type
Fields
entity_ref: EntityReferenceImplementations
Sourceimpl<S, M, C> Placement<S, M, C>
impl<S, M, C> Placement<S, M, C>
pub fn new(entity_ref: EntityReference, candidates: C) -> Self
pub fn with_keep_current_legal(self, legal: bool) -> Self
pub fn keep_current_legal(&self) -> bool
pub fn candidates(&self) -> &C
pub fn candidates_mut(&mut self) -> &mut C
pub fn take_move(&mut self, candidate_id: CandidateId) -> M