pub struct SoftScoreBounder;Expand description
A simple bounder that uses the current score as the optimistic bound.
This is useful when constraint violations can only increase (get worse) as more assignments are made, which is common for most constraint problems.
Implementations