Module localsearch

Module localsearch 

Structs

AcceptedCountForager
A forager that stops after N accepted moves and picks the best of them.
BestScoreForager
A forager that evaluates all accepted moves and picks the best.
DiversifiedLateAcceptanceAcceptor
Diversified late acceptance acceptor - combines late acceptance with best score tracking.
FirstAcceptedForager
A forager that picks the first accepted move.
FirstBestScoreImprovingForager
A forager that picks the first accepted move that improves on the best score ever seen.
FirstLastStepScoreImprovingForager
A forager that picks the first accepted move that improves on the last step’s score.
GreatDelugeAcceptor
Great Deluge acceptor - accepts moves above a rising water level.
HillClimbingAcceptor
LateAcceptanceAcceptor
Late acceptance acceptor - accepts moves that improve on a historical score.
LocalSearchPhase
Local search phase that improves an existing solution.
SimulatedAnnealingAcceptor
SimulatedAnnealingCalibration
StepCountingHillClimbingAcceptor
Step Counting Hill Climbing acceptor - allows limited non-improving moves.
TabuSearchAcceptor
Canonical metadata-based tabu search acceptor.

Enums

ForagerDecision
Tells the phase which candidate payload remains owned after online foraging.
HardRegressionPolicy

Traits

Acceptor
Trait for accepting or rejecting moves in local search.
LocalSearchForager
Trait for collecting and selecting moves in local search.
MoveCursorSource
Opens the next phase cursor from mutable solve-owned execution state.