Module partitioned

Module partitioned 

Structs

FunctionalPartitioner
A simple partitioner that creates a specified number of partitions.
PartitionedSearchConfig
PartitionedSearchPhase
Partitioned search phase that solves partitions in parallel.

Enums

ThreadCount

Traits

ChildPhases
Trait for child phases that can solve a partition.
SolutionPartitioner
Splits a solution into independent partitions for parallel solving.