pub struct CoverageGroupLimits {
pub value_candidate_limit: Option<usize>,
pub group_candidate_limit: Option<usize>,
pub max_moves_per_step: Option<usize>,
pub max_augmenting_depth: Option<usize>,
}Fields
value_candidate_limit: Option<usize>Caps candidate values considered for each entity in construction and repair.
group_candidate_limit: Option<usize>Caps group-level construction candidates. Repair selectors do not read this limit.
max_moves_per_step: Option<usize>Caps moves emitted by coverage repair selectors. Construction does not read this limit.
max_augmenting_depth: Option<usize>Caps the recursive augmenting path depth used while relocating blockers.
Implementations