Module run

Module run 

Unified solver entry point.

This module provides the single run_solver function used by both basic variable and list variable problems via the ProblemSpec trait.

Enums

AnyTermination
Monomorphized termination enum for config-driven solver configurations.

Functions

build_termination
Builds a termination from config, returning both the termination and the time limit.
run_solver
Solves a problem using the given ProblemSpec for problem-specific logic.