pub fn build_termination<S, C>(
config: &SolverConfig,
default_secs: u64,
) -> (AnyTermination<S, ScoreDirector<S, C>>, Duration)Expand description
Builds a termination from config, returning both the termination and the time limit.
pub fn build_termination<S, C>(
config: &SolverConfig,
default_secs: u64,
) -> (AnyTermination<S, ScoreDirector<S, C>>, Duration)Builds a termination from config, returning both the termination and the time limit.