Module solver

Module solver 

Solver implementation.

Structs

NoTermination
Marker type indicating no termination.
SolveResult
Result of a solve operation containing solution and telemetry.
Solver
The main solver that optimizes planning solutions.

Traits

MaybeTermination
Marker trait for termination types that can be used in Solver.