pub struct MoveTelemetry {Show 14 fields
pub move_label: String,
pub moves_generated: u64,
pub moves_evaluated: u64,
pub moves_accepted: u64,
pub moves_applied: u64,
pub moves_not_doable: u64,
pub moves_acceptor_rejected: u64,
pub moves_forager_ignored: u64,
pub moves_score_improving: u64,
pub moves_applied_improving: u64,
pub moves_score_equal: u64,
pub moves_score_worse: u64,
pub moves_rejected_improving: u64,
pub applied_score_improvement: f64,
}Fields
move_label: Stringmoves_generated: u64Candidate moves actually yielded to the engine across all phases. Exhaust a cursor or query selector sizing separately for logical size.
moves_evaluated: u64moves_accepted: u64moves_applied: u64moves_not_doable: u64moves_acceptor_rejected: u64moves_forager_ignored: u64moves_score_improving: u64moves_applied_improving: u64moves_score_equal: u64moves_score_worse: u64moves_rejected_improving: u64applied_score_improvement: f64Trait Implementations
Sourceimpl Clone for MoveTelemetry
impl Clone for MoveTelemetry
Sourcefn clone(&self) -> MoveTelemetry
fn clone(&self) -> MoveTelemetry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MoveTelemetry
impl Debug for MoveTelemetry
Sourceimpl Default for MoveTelemetry
impl Default for MoveTelemetry
Sourcefn default() -> MoveTelemetry
fn default() -> MoveTelemetry
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for MoveTelemetry
impl PartialEq for MoveTelemetry
impl StructuralPartialEq for MoveTelemetry