pub struct PhaseTelemetry {Show 13 fields
pub phase_index: usize,
pub phase_type: String,
pub elapsed: Duration,
pub step_count: u64,
pub moves_generated: u64,
pub moves_evaluated: u64,
pub moves_accepted: u64,
pub moves_applied: u64,
pub moves_score_improving: u64,
pub moves_applied_improving: u64,
pub score_calculations: u64,
pub generation_time: Duration,
pub evaluation_time: Duration,
}Fields
phase_index: usizephase_type: Stringelapsed: Durationstep_count: u64moves_generated: u64Candidate moves actually yielded to the engine during this phase. This is runtime work, not the size of an unconsumed neighborhood.
moves_evaluated: u64moves_accepted: u64moves_applied: u64moves_score_improving: u64moves_applied_improving: u64score_calculations: u64generation_time: Durationevaluation_time: DurationTrait Implementations
Sourceimpl Clone for PhaseTelemetry
impl Clone for PhaseTelemetry
Sourcefn clone(&self) -> PhaseTelemetry
fn clone(&self) -> PhaseTelemetry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PhaseTelemetry
impl Debug for PhaseTelemetry
Sourceimpl Default for PhaseTelemetry
impl Default for PhaseTelemetry
Sourcefn default() -> PhaseTelemetry
fn default() -> PhaseTelemetry
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for PhaseTelemetry
impl PartialEq for PhaseTelemetry
impl StructuralPartialEq for PhaseTelemetry