Context types that carry domain function pointers into the builder layer.
Structs
- Basic
Context - Function-pointer context for basic (non-list) variable solvers.
- List
Context - Function-pointer context for list variable solvers.
Context types that carry domain function pointers into the builder layer.