Module move

Module move 

Modules

k_opt_reconnection

Structs

ChangeMove
A move that assigns a value to an entity’s variable.
CompositeMove
A move that applies two moves in sequence via arena indices.
CutPoint
KOptMove
A k-opt move that removes k edges and reconnects segments.
ListChangeMove
A move that relocates an element from one list position to another.
ListReverseMove
A move that reverses a segment within a list.
ListRuinMove
A ruin-and-recreate move for Large Neighborhood Search on list variables.
ListSwapMove
A move that swaps two elements in list variables.
MoveArena
Arena allocator for moves with O(1) reset.
PillarChangeMove
A move that assigns a value to all entities in a pillar.
PillarSwapMove
A move that swaps values between two pillars.
RuinMove
A move that unassigns multiple entities for Large Neighborhood Search.
SubListChangeMove
A move that relocates a contiguous sublist from one position to another.
SubListSwapMove
A move that swaps two contiguous sublists.
SwapMove
A move that swaps values between two entities.

Enums

EitherMove
A monomorphized union of ChangeMove and SwapMove.
ListMoveImpl
A monomorphized union of all list-variable move types.

Traits

Move
A move that modifies one or more planning variables.