Module value_selector

Module value_selector 

Structs

FromSolutionValueSelector
A value selector that extracts values from the solution using a function pointer.
PerEntityValueSelector
RangeValueSelector
A value selector that generates a range of usize values 0..count.
StaticValueSelector
A value selector with a static list of values.

Traits

ValueSelector
A value selector that yields values of type V directly.