pub trait ScoreBounder<S: PlanningSolution, D: Director<S>>: Send + Debug {
// Required method
fn calculate_optimistic_bound(&self, score_director: &D) -> Option<S::Score>;
// Provided method
fn calculate_pessimistic_bound(
&self,
score_director: &D,
) -> Option<S::Score> { ... }
}Expand description
Calculates score bounds for exhaustive search pruning.
The bounder estimates the best possible score that can be achieved from a partial solution state. If this optimistic bound is worse than the best complete solution found so far, the branch can be pruned.