Acceptor

Trait Acceptor 

pub trait Acceptor<S: PlanningSolution>: Send + Debug {
    // Required method
    fn is_accepted(
        &mut self,
        last_step_score: &S::Score,
        move_score: &S::Score,
    ) -> bool;

    // Provided methods
    fn phase_started(&mut self, _initial_score: &S::Score) { ... }
    fn phase_ended(&mut self) { ... }
    fn step_started(&mut self) { ... }
    fn step_ended(&mut self, _step_score: &S::Score) { ... }
}
Trait for accepting or rejecting moves in local search.

Acceptors implement different strategies for escaping local optima, such as hill climbing, simulated annealing, or tabu search.

Required Methods

fn is_accepted( &mut self, last_step_score: &S::Score, move_score: &S::Score, ) -> bool

Provided Methods

fn phase_started(&mut self, _initial_score: &S::Score)

fn phase_ended(&mut self)

fn step_started(&mut self)

fn step_ended(&mut self, _step_score: &S::Score)

Implementors