pub fn build_termination<S, C>(
config: &SolverConfig,
default_secs: u64,
) -> (AnyTermination<S, ScoreDirector<S, C>>, Option<Duration>)Expand description
Builds a termination from config, returning both the termination and the time limit.
pub fn build_termination<S, C>(
config: &SolverConfig,
default_secs: u64,
) -> (AnyTermination<S, ScoreDirector<S, C>>, Option<Duration>)Builds a termination from config, returning both the termination and the time limit.