pub struct PhaseStats {
pub phase_index: usize,
pub phase_type: &'static str,
pub step_count: u64,
pub moves_generated: u64,
pub moves_evaluated: u64,
pub moves_accepted: u64,
pub score_calculations: u64,
/* private fields */
}Fields
phase_index: usizephase_type: &'static strstep_count: u64moves_generated: u64moves_evaluated: u64moves_accepted: u64score_calculations: u64Implementations
Sourceimpl PhaseStats
impl PhaseStats
pub fn elapsed(&self) -> Duration
Sourcepub fn record_step(&mut self)
pub fn record_step(&mut self)
Records a step completion.
Sourcepub fn record_generated_batch(&mut self, count: u64, duration: Duration)
pub fn record_generated_batch(&mut self, count: u64, duration: Duration)
Records one or more generated candidate moves and the time spent generating them.
Sourcepub fn record_generation_time(&mut self, duration: Duration)
pub fn record_generation_time(&mut self, duration: Duration)
Records generation time that did not itself yield a counted move.
Sourcepub fn record_generated_move(&mut self, duration: Duration)
pub fn record_generated_move(&mut self, duration: Duration)
Records a single generated candidate move and the time spent generating it.
Sourcepub fn record_evaluated_move(&mut self, duration: Duration)
pub fn record_evaluated_move(&mut self, duration: Duration)
Records a move evaluation and the time spent evaluating it.
Sourcepub fn record_move_accepted(&mut self)
pub fn record_move_accepted(&mut self)
Records an accepted move.
Sourcepub fn record_score_calculation(&mut self)
pub fn record_score_calculation(&mut self)
Records a score calculation.
pub fn generated_throughput(&self) -> Throughput
pub fn evaluated_throughput(&self) -> Throughput
pub fn acceptance_rate(&self) -> f64
pub fn generation_time(&self) -> Duration
pub fn evaluation_time(&self) -> Duration